@@ -1,6 +1,6 @@
 #!/usr/bin/perl -w
 
-# $Id: clamdsh.pl,v 1.14 2007/06/16 17:18:34 okamura Exp $
+# $Id: clamdsh.pl,v 1.15 2007/06/16 21:14:55 okamura Exp $
 
 require 5.8.0;
 use strict;
@@ -37,7 +37,7 @@ use vars qw(
 # 定数
 #-------------------------------------------------------------------------------
 # バージョン
-$Version = 'clamdsh.pl v1.1.1';
+$Version = 'clamdsh.pl v1.1.2';
 
 # 終了ステータス
 %ExitStatus = (
@@ -411,14 +411,38 @@ sub InterpretString {
 				)|c.(?#						コントロール文字
 				)|l.(?#						一文字の小文字
 				)|u.(?#						一文字の大文字
-				)|L(?:[^\\]|\\[^E])*\E(?#	小文字
-				)|U(?:[^\\]|\\[^E])*\E(?#	大文字
-				)|Q(?:[^\\]|\\[^E])*\E(?#	クォート
+				)|L(?:[^\\]|\\[^E])*\\E(?#	小文字
+				)|U(?:[^\\]|\\[^E])*\\E(?#	大文字
+				)|Q(?:[^\\]|\\[^E])*\\E(?#	クォート
 				))/
 			) {
 				my	$token = $1;
-				my	$escaped = "\"\\$token\"";
-				my	$unescaped = eval "
+				my	$escaped;
+				my	$unescaped;
+
+				$escaped = $token;
+				if (0 <= index($escaped, '"')) {
+					my	$rest = $escaped;
+
+					$escaped = '';
+					while ($rest =~ m/\\*"/) {
+						my	$prematch = $`;
+						my	$match = $&;
+						my	$postmatch = $';
+
+						$escaped .= $prematch;
+						if (length($match) % 2) {
+							$escaped .= "\\".$match;
+						}
+						else {
+							$escaped .= $match;
+						}
+						$rest = $postmatch;
+					}
+					$escaped .= $rest;
+				}
+				$escaped = '"\\'.$escaped.'"';
+				$unescaped = eval "
 					use charnames	qw(:full);
 					$escaped;
 				";
